Py4JServerConnection (py4j-java 0.10.9.7 API)

Package py4j

## Interface Py4JServerConnection

- All Known Implementing Classes:
    `ClientServerConnection`, `GatewayConnection`

      public interface Py4JServerConnection

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `java.net.Socket` | `getSocket()` |
    `void` | `shutdown()` |
    `void` | `shutdown​(boolean reset)` |

- - ### Method Detail

    - #### getSocket

          java.net.Socket getSocket()

      Returns:
        The socket used by this gateway connection.

    - #### shutdown

          void shutdown()

    - #### shutdown

          void shutdown​(boolean reset)